@@ -10,11 +10,13 @@ from graph_partition.evaluation_metric.getClusterDiameter import GetClusterDiame
 from graph_partition.evaluation_metric.getClusteringCost import GetClusteringCost
 
 
-def evaluate_clustering_metrics(cost_matrix: List[List], class_label: List):
+def evaluate_clustering_metrics(
+    cost_matrix: List[List], class_label: List, num_cluster: int
+):
     # Calculating the actual cost and other metrics
-    _actual_cost = GetClusteringCost(cost_matrix, class_label)
-    _arm = GetAgreementRateMetric(cost_matrix, class_label)
-    _dia = GetClusterDiameter(cost_matrix, class_label)
+    _actual_cost = GetClusteringCost(cost_matrix, class_label, num_cluster)
+    _arm = GetAgreementRateMetric(cost_matrix, class_label, num_cluster)
+    _dia = GetClusterDiameter(cost_matrix, class_label, num_cluster)
     _min_cluster, _max_cluster, _cif = measure_cluster_imbalance(class_label)
     _evaluation_metrics = {
         "cost": round(_actual_cost.cost, 4),
