@@ -18,15 +18,21 @@ class GetAgreementRateMetric:
 
     _k_ = 12
 
-    def __init__(self, cost_matrix: List[List[Union[float, int]]], cluster_list: List):
+    def __init__(
+        self,
+        cost_matrix: List[List[Union[float, int]]],
+        cluster_label: List,
+        num_cluster: int,
+    ):
         self.cost_matrix = cost_matrix
-        self.cluster_list = cluster_list
+        self.cluster_label = cluster_label
+        self.num_cluster = num_cluster
         self.dimension = len(cost_matrix)
         # If the dimension is less than the neighbour
         self._k_ = min(self.dimension, self._k_)
         # Converting the cluster list to label list
         self.cluster_label = self.__convert_cluster_list__(
-            cluster_list=self.cluster_list
+            cluster_label=self.cluster_label, num_cluster=num_cluster
         )
         assert len(self.cluster_label) == self.dimension, (
             f"dimension of cost matrix {self.dimension} and "
@@ -52,14 +58,13 @@ class GetAgreementRateMetric:
         self.ARM = _arm / (self._k_ * self.dimension)
 
     @classmethod
-    def __convert_cluster_list__(cls, cluster_list: List) -> List:
-        if isinstance(cluster_list[0], int):
-            return cluster_list
+    def __convert_cluster_list__(cls, cluster_label: List, num_cluster: int) -> List:
+        if isinstance(cluster_label[0], int):
+            return cluster_label
         else:
-            num_clusters = len(cluster_list)
-            dimension = sum([len(x[1]) for x in cluster_list])
+            dimension = sum([len(x[1]) for x in cluster_label])
             _cluster_label = np.zeros(dimension)
-            for c in range(num_clusters):
-                for order in cluster_list[c][1]:
+            for c in range(num_cluster):
+                for order in cluster_label[c][1]:
                     _cluster_label[order.order_sequence] = c
             return [int(x) for x in _cluster_label]
