@@ -3,10 +3,14 @@ from typing import List, Union, Tuple
 
 class GetClusterDiameter:
     def __init__(
-        self, cost_matrix: List[List[Union[float, int]]], cluster_label: List[int]
+        self,
+        cost_matrix: List[List[Union[float, int]]],
+        cluster_label: List[int],
+        num_cluster: int,
     ):
         self.cost_matrix = cost_matrix
         self.cluster_label = cluster_label
+        self.num_cluster = num_cluster
         self.dimension = len(cost_matrix)
 
         assert (
@@ -56,7 +60,7 @@ class GetClusterDiameter:
             )
 
     def _calculate_diameters(self):
-        _unique_clusters = list(set(self.cluster_label))
+        _unique_clusters = list(range(self.num_cluster))
         for lbl in _unique_clusters:
             _dia, _distance_sum = self._calculate_diameter(lbl)
             self.cluster_diameters = (lbl, _dia)
