@@ -11,7 +11,6 @@ from graph_partition.gcn.buildGraphConvolution import BuildGraphConvolution
 
 
 class GraphConvolutionNetwork:
-    __early_stopping_round__ = 10000
     __tolerance__ = 1e-04
 
     def __init__(
@@ -19,7 +18,9 @@ class GraphConvolutionNetwork:
         cost_matrix: ndarray,
         num_class: int,
         hidden_layers: Union[List[int], int],
+        adjacency_matrix: ndarray = None,
         feature_matrix: ndarray = None,
+        early_stopping_round: int = 10_000,
         learning_rate: float = 0.0001,
         use_learning_rate_scheduler: bool = False,
         l2_penalty: float = 0,
@@ -33,7 +34,9 @@ class GraphConvolutionNetwork:
         :param cost_matrix: The cost matrix is typically the routing distance or euclidean distance from one point to another
         :param num_class: The number of clusters
         :param hidden_layers: Hidden Layers, it can be a list of integers or a single integer
+        :param adjacency_matrix: Explicitly we can mention the adjacency matrix, else it will be calculated from the cost matrix
         :param feature_matrix: Default is none, if there is any node level signal or features, we can use that for clustering
+        :param early_stopping_round, the rounds which will check number of rounds model didn't improve
         :param learning_rate: Learning rate of the weights updation
         :param use_learning_rate_scheduler: True or False, if we want to use the same learning rate throughout the training process we can make False,
         if we want to decay over the time we need to make it True, Default is False
@@ -48,7 +51,12 @@ class GraphConvolutionNetwork:
         print(f"{self._device} will be used for computation \n")
 
         self.cost_matrix = from_numpy(cost_matrix.astype(np.float64)).to(self._device)
-        self.adjacency_matrix = self.get_adjacency_matrix()
+        if adjacency_matrix is None:
+            self.adjacency_matrix = self.get_adjacency_matrix()
+        else:
+            self.adjacency_matrix = from_numpy(adjacency_matrix.astype(np.float64)).to(
+                self._device
+            )
         # Calculation of feature matrix, if nodes doesn't have any
         # features/signals then we can simply use an identity matrix
         if feature_matrix is None:
@@ -59,6 +67,7 @@ class GraphConvolutionNetwork:
             self.feature_matrix = from_numpy(feature_matrix.astype(np.float64)).to(
                 self._device
             )
+        self.early_stopping_round = early_stopping_round
         # Hidden Layers
         if isinstance(hidden_layers, int):
             self.hidden_layers = [hidden_layers]
@@ -108,6 +117,9 @@ class GraphConvolutionNetwork:
         self.cluster_label: List = []
         self.evaluation_metric: Dict[str, Any] = {}
 
+        # fit
+        self.fit()
+
     def fit(self):
         loss_list = []
         _min_loss = 1e09
@@ -151,8 +163,8 @@ class GraphConvolutionNetwork:
             if self.scheduler:
                 self._scheduler.step()
 
-            loss_list.append(_loss.item())
-            _min_loss = _loss.item() if _loss.item() < _min_loss else _min_loss
+            loss_list.append(_loss.detach().item())
+            _min_loss = _loss.detach().item() if _loss.item() < _min_loss else _min_loss
             # Verbose
             if (e + 1) % 1000 == 0:
                 print(
@@ -190,7 +202,9 @@ class GraphConvolutionNetwork:
         # Training is completed now predicting the class labels
         self.cluster_label = self.predict()
         self.evaluation_metric = evaluate_clustering_metrics(
-            self.cost_matrix.to("cpu").numpy().tolist(), self.cluster_label
+            self.cost_matrix.to("cpu").numpy().tolist(),
+            self.cluster_label,
+            self.num_class,
         )
 
     def predict(self, X: Tensor = None) -> List:
@@ -204,10 +218,15 @@ class GraphConvolutionNetwork:
         return _cluster_label
 
     def early_stopping(self, loss_list: list, min_loss: float) -> bool:
-        if len(loss_list) < 10 + self.__early_stopping_round__:
+        if len(loss_list) < 10 + self.early_stopping_round:
             return False
         else:
-            if all([x > min_loss for x in loss_list[-self.__early_stopping_round__ :]]):
+            if all(
+                [
+                    abs(x - min_loss) < self.__tolerance__
+                    for x in loss_list[-self.early_stopping_round :]
+                ]
+            ):
                 return True
             else:
                 return False
