@@ -39,7 +39,7 @@ class ConstrainedKMeans:
                 self.design_matrix, self.design_matrix
             ).tolist()
             self.evaluation_metric = evaluate_clustering_metrics(
-                _cost_matrix, self.cluster_label
+                _cost_matrix, self.cluster_label, self.num_class
             )
         else:
             self.evaluation_metric = None
