@@ -12,11 +12,11 @@ class SpectralClustering:
         self, cost_matrix: List[List], num_class: int, constrained: bool = True
     ):
         self.cost_matrix = cost_matrix
-        self.number_of_clusters = num_class
+        self.num_cluster = num_class
         self.constrained = constrained
         self.cluster_label = self.cluster()
         self.evaluation_metric = evaluate_clustering_metrics(
-            self.cost_matrix, self.cluster_label
+            self.cost_matrix, self.cluster_label, self.num_cluster
         )
 
     def transform(self):
@@ -38,7 +38,7 @@ class SpectralClustering:
         # Discard the first eigen vector
         _k_means_model = ConstrainedKMeans(
             _eigen_vectors[:, 1:],
-            num_class=self.number_of_clusters,
+            num_class=self.num_cluster,
             constrained=self.constrained,
         )
         return _k_means_model.cluster_label
